@@ -170,13 +170,13 @@ format.profile_data <- function(x, ...) {
 #'
 #' @rdname validate_profile
 #' @export
-#' @examples
+#' @examplesIf rlang::is_installed("dm")
 #'
-#' if (rlang::is_installed("dm")) {
-#'   dm <- dm_from_profile(ds)
-#'   print(dm)
-#'   dm::dm_draw(dm)
-#' }
+#' dm <- dm_from_profile(ds)
+#' print(dm)
+#' @examplesIf rlang::is_installed(c("dm", "DiagrammeR"))
+#'
+#' dm::dm_draw(dm)
 dm_from_profile <- function(x) {
   stopifnot(inherits(x, "profile_data"))
   stopifnot(rlang::is_installed("dm"))
@@ -187,7 +187,7 @@ dm_from_profile <- function(x) {
   samples$sample_id <- seq_len(nrow(samples))
   samples_locations <- tibble::tibble(
     sample_id = rep(samples$sample_id, vapply(samples$locations, nrow, integer(1))),
-    location_id = tibble::as_tibble(do.call(rbind, samples$locations))
+    tibble::as_tibble(do.call(rbind, samples$locations))
   )
   samples$locations <- NULL
 
